var searchData=
[
  ['uav_0',['Uav',['../struct_ogre_1_1_compute_property.html#a5503ecbcbeee97d79ef0b14c2cac9e85',1,'Ogre::ComputeProperty']]],
  ['uavslot_1',['uavSlot',['../struct_ogre_1_1_compositor_pass_def_1_1_uav_dependency.html#aab25d55f5aa42cf5023019852d31d703',1,'Ogre::CompositorPassDef::UavDependency::uavSlot'],['../struct_ogre_1_1_compositor_pass_uav_def_1_1_texture_source.html#af9042829bedad027e8d4e16b71a2410e',1,'Ogre::CompositorPassUavDef::TextureSource::uavSlot'],['../struct_ogre_1_1_compositor_pass_uav_def_1_1_buffer_source.html#a77995f21324680367561115d74307193',1,'Ogre::CompositorPassUavDef::BufferSource::uavSlot']]],
  ['uintbuffersize_2',['uintBufferSize',['../struct_ogre_1_1_gpu_named_constants.html#aa78a9520e9515038318893626480112c',1,'Ogre::GpuNamedConstants']]],
  ['uncompressedsize_3',['uncompressedSize',['../struct_ogre_1_1_file_info.html#a66c7bf4f59feb619016a5c70e4ded4ee',1,'Ogre::FileInfo']]],
  ['uninitialized_5fcollapse_5fcost_4',['UNINITIALIZED_COLLAPSE_COST',['../struct_ogre_1_1_lod_data.html#af95ac40c4f3bdd402aa2e0cc1e25fc9c',1,'Ogre::LodData']]],
  ['unit_5fscale_5',['UNIT_SCALE',['../class_ogre_1_1_array_vector3.html#a430a0a90f2cdab4764844a276636a2d9',1,'Ogre::ArrayVector3::UNIT_SCALE'],['../class_ogre_1_1_vector2.html#a165a67053e61b0733746453ce9ee5edb',1,'Ogre::Vector2::UNIT_SCALE'],['../class_ogre_1_1_vector3.html#a6a27e8a3a9156701f586afeed1516fb8',1,'Ogre::Vector3::UNIT_SCALE']]],
  ['unit_5fx_6',['UNIT_X',['../class_ogre_1_1_array_vector3.html#a811d19510f8352453fa8f86d8c226a49',1,'Ogre::ArrayVector3::UNIT_X'],['../class_ogre_1_1_vector2.html#a1c2d210b2756d07375b0cf9f01835496',1,'Ogre::Vector2::UNIT_X'],['../class_ogre_1_1_vector3.html#a0c21d1f120c5eab83aa966e5de1df311',1,'Ogre::Vector3::UNIT_X']]],
  ['unit_5fy_7',['UNIT_Y',['../class_ogre_1_1_array_vector3.html#a6a152308d886080433232254917bb4bb',1,'Ogre::ArrayVector3::UNIT_Y'],['../class_ogre_1_1_vector2.html#ad20c8c58c9345a71743416bad82cb5e3',1,'Ogre::Vector2::UNIT_Y'],['../class_ogre_1_1_vector3.html#a8d1a1f7af535bcc8d9c78b1732bc1b90',1,'Ogre::Vector3::UNIT_Y']]],
  ['unit_5fz_8',['UNIT_Z',['../class_ogre_1_1_array_vector3.html#a1fcb417792cf81b60dcfaa0ec77b150f',1,'Ogre::ArrayVector3::UNIT_Z'],['../class_ogre_1_1_vector3.html#ad25aed2e9367cfa879d3e3c231c5a136',1,'Ogre::Vector3::UNIT_Z']]],
  ['uoffset_9',['uOffset',['../struct_ogre_1_1_pbs_uv_atlas_params.html#ae3e62227806f0f245db9618bab213e70',1,'Ogre::PbsUvAtlasParams::uOffset'],['../struct_ogre_1_1_hlms_unlit_mobile_datablock_1_1_uv_atlas_params.html#a091bb9697df5e809531a630e33527778',1,'Ogre::HlmsUnlitMobileDatablock::UvAtlasParams::uOffset']]],
  ['updatefrom_10',['updateFrom',['../struct_ogre_1_1_volume_1_1_chunk_parameters.html#aeefacd1d618206fcb432ed947b58e06e',1,'Ogre::Volume::ChunkParameters']]],
  ['updateto_11',['updateTo',['../struct_ogre_1_1_volume_1_1_chunk_parameters.html#afe30999e8cc71a1f48d87d68bf43059d',1,'Ogre::Volume::ChunkParameters']]],
  ['usage_12',['usage',['../struct_ogre_1_1_vulkan_device_1_1_selected_queue.html#ad3b70ed4aed581a14a7eb46f9499222b',1,'Ogre::VulkanDevice::SelectedQueue']]],
  ['usebackgroundqueue_13',['useBackgroundQueue',['../struct_ogre_1_1_lod_config_1_1_advanced.html#af0b0ebeed034ed3d63ea1bfc3c36fab0',1,'Ogre::LodConfig::Advanced']]],
  ['usecompression_14',['useCompression',['../struct_ogre_1_1_lod_config_1_1_advanced.html#a170e01ea28652c19ec4d610c0b491ab7',1,'Ogre::LodConfig::Advanced']]],
  ['usecount_15',['useCount',['../struct_ogre_1_1_shared_ptr_info.html#a18b7520ec0d1a7d2617344a88204cb4d',1,'Ogre::SharedPtrInfo']]],
  ['usedcount_16',['usedCount',['../struct_ogre_1_1_vertices_remap_info.html#a644d1183b273a67df318aca5041bee6c',1,'Ogre::VerticesRemapInfo']]],
  ['usedmemory_17',['usedMemory',['../struct_ogre_1_1_texture_pool.html#a4b6d352df8ce643f8e39d1b073bd3be4',1,'Ogre::TexturePool']]],
  ['usedslots_18',['usedSlots',['../struct_ogre_1_1_texture_pool.html#a12bc237f86b8626243426104b714b23a',1,'Ogre::TexturePool']]],
  ['useenvprobemap_19',['UseEnvProbeMap',['../struct_ogre_1_1_pbs_property.html#ac95a51ebb023e4ace2d2960af52114bb',1,'Ogre::PbsProperty']]],
  ['usefullscreen_20',['useFullScreen',['../struct_ogre_1_1_render_window_description.html#a5809e1727a29bbc2737e090ab338c6a7',1,'Ogre::RenderWindowDescription']]],
  ['useglobalinstancingvertexbufferisavailable_21',['useGlobalInstancingVertexBufferIsAvailable',['../class_ogre_1_1v1_1_1_render_operation.html#ad3cea3ec309e152738732daf042fe7af',1,'Ogre::v1::RenderOperation']]],
  ['useindexes_22',['useIndexes',['../class_ogre_1_1v1_1_1_render_operation.html#ae0388dc9cba45cc2dd7287e95291239f',1,'Ogre::v1::RenderOperation']]],
  ['uselightbuffers_23',['useLightBuffers',['../struct_ogre_1_1_pbs_property.html#abe7aa4691c2404ff13e12cb858e73c53',1,'Ogre::PbsProperty']]],
  ['useparallaxcorrectcubemaps_24',['UseParallaxCorrectCubemaps',['../struct_ogre_1_1_pbs_property.html#a8c7e50d9f8e435a4f15f1ecfbc5acb53',1,'Ogre::PbsProperty']]],
  ['useplanarreflections_25',['UsePlanarReflections',['../struct_ogre_1_1_pbs_property.html#a490cd8b3533095bcbb34f1c70f833d0d',1,'Ogre::PbsProperty']]],
  ['useprepass_26',['UsePrePass',['../struct_ogre_1_1_hlms_base_prop.html#aa112290f96cf14277b193cf6da591b29',1,'Ogre::HlmsBaseProp']]],
  ['useprepassmsaa_27',['UsePrePassMsaa',['../struct_ogre_1_1_hlms_base_prop.html#a7440f6aa5bafdb97858f837f2b884af1',1,'Ogre::HlmsBaseProp']]],
  ['usereadonlybuffers_28',['useReadOnlyBuffers',['../struct_ogre_1_1_const_buffer_pool_1_1_extra_buffer_params.html#a084feec90243a88616ecac8cb98e1cfe',1,'Ogre::ConstBufferPool::ExtraBufferParams']]],
  ['uservalue_29',['userValue',['../struct_ogre_1_1v1_1_1_mesh_lod_usage.html#abfaf37d771b30297bd76fab8ea565089',1,'Ogre::v1::MeshLodUsage']]],
  ['usesallfields_30',['usesAllFields',['../struct_ogre_1_1_compositor_pass_compute_def_1_1_compute_texture_source.html#a56aac178742acf3ceabe85e56f61049c',1,'Ogre::CompositorPassComputeDef::ComputeTextureSource']]],
  ['usesharedvertexbuffer_31',['useSharedVertexBuffer',['../struct_ogre_1_1_lod_input_buffer_1_1_submesh.html#a575926e31feb1cc9bfebab8a13fded97',1,'Ogre::LodInputBuffer::Submesh']]],
  ['usesharedvertices_32',['useSharedVertices',['../class_ogre_1_1v1_1_1_sub_mesh.html#a0dfb168c4576b29b656466f2a571c372',1,'Ogre::v1::SubMesh']]],
  ['usessr_33',['UseSsr',['../struct_ogre_1_1_hlms_base_prop.html#af5caaaf083c61c9af0aeafe39c702267',1,'Ogre::HlmsBaseProp']]],
  ['usesvertextexturefetch_34',['usesVertexTextureFetch',['../struct_ogre_1_1_material_script_program_definition.html#a4fdff24708148cef3ede00b2e6abade8',1,'Ogre::MaterialScriptProgramDefinition']]],
  ['usetexturealpha_35',['UseTextureAlpha',['../struct_ogre_1_1_pbs_property.html#ab512ebe1ce98714f4ac942943c3d5c4c',1,'Ogre::PbsProperty']]],
  ['useuvbaking_36',['UseUvBaking',['../struct_ogre_1_1_hlms_base_prop.html#afc55cb97073522c4585321ad6ce83c5b',1,'Ogre::HlmsBaseProp']]],
  ['usevertexnormals_37',['useVertexNormals',['../struct_ogre_1_1_lod_config_1_1_advanced.html#aa510662a645fab3ef85ef4b1cde1a7a2',1,'Ogre::LodConfig::Advanced']]],
  ['uvatlas_38',['UvAtlas',['../struct_ogre_1_1_pbs_mobile_property.html#a888d7269bc4a8653824979f814fd5846',1,'Ogre::PbsMobileProperty::UvAtlas'],['../struct_ogre_1_1_unlit_mobile_prop.html#a985bb730dc4aca48ef9c30e015da8b57',1,'Ogre::UnlitMobileProp::UvAtlas']]],
  ['uvatlas0_39',['UvAtlas0',['../struct_ogre_1_1_unlit_mobile_prop.html#a49bb1dcfc1172c21faaafd92b548a51a',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas1_40',['UvAtlas1',['../struct_ogre_1_1_unlit_mobile_prop.html#ab41a53b67e14fc9ad9c87b3420d96db6',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas10_41',['UvAtlas10',['../struct_ogre_1_1_unlit_mobile_prop.html#ad2a43eea8886d2515156c12350244ef7',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas11_42',['UvAtlas11',['../struct_ogre_1_1_unlit_mobile_prop.html#aeed49299be524befb68e94755cd8ff29',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas12_43',['UvAtlas12',['../struct_ogre_1_1_unlit_mobile_prop.html#a51f3f290f6c1ea9414c4268be8ff5cbc',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas13_44',['UvAtlas13',['../struct_ogre_1_1_unlit_mobile_prop.html#a4d86d67193f6f620509c171c31bce327',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas14_45',['UvAtlas14',['../struct_ogre_1_1_unlit_mobile_prop.html#a125f8f6bb5c465ea6782a69f3eca36c7',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas15_46',['UvAtlas15',['../struct_ogre_1_1_unlit_mobile_prop.html#ae140aad7a64b075322f7301247ceac5e',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas2_47',['UvAtlas2',['../struct_ogre_1_1_unlit_mobile_prop.html#a0612fdd3dfee088942760524d632912b',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas3_48',['UvAtlas3',['../struct_ogre_1_1_unlit_mobile_prop.html#af94f977686a8f46c2c39db4970e03bf7',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas4_49',['UvAtlas4',['../struct_ogre_1_1_unlit_mobile_prop.html#a9e107578797e694126dcb30099df6b0a',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas5_50',['UvAtlas5',['../struct_ogre_1_1_unlit_mobile_prop.html#aa18a3c615ef767cefbf064e50f11591f',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas6_51',['UvAtlas6',['../struct_ogre_1_1_unlit_mobile_prop.html#a8ea1e72827a6fcb13f1bc60c2b11548d',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas7_52',['UvAtlas7',['../struct_ogre_1_1_unlit_mobile_prop.html#a86596afdfa629383080c8485c589a64b',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas8_53',['UvAtlas8',['../struct_ogre_1_1_unlit_mobile_prop.html#a793f6cd0d716c0e63fa2b91b5e40b74c',1,'Ogre::UnlitMobileProp']]],
  ['uvatlas9_54',['UvAtlas9',['../struct_ogre_1_1_unlit_mobile_prop.html#ae6374a2db87d42780b6561f05129d4e5',1,'Ogre::UnlitMobileProp']]],
  ['uvbaking_55',['UvBaking',['../struct_ogre_1_1_hlms_base_prop.html#aed1ad09e3a75eb803111f5a9e8971d13',1,'Ogre::HlmsBaseProp']]],
  ['uvcount_56',['UvCount',['../struct_ogre_1_1_hlms_base_prop.html#aff59c800dc28ed12f86cf40cfa576ad1',1,'Ogre::HlmsBaseProp']]],
  ['uvcount0_57',['UvCount0',['../struct_ogre_1_1_hlms_base_prop.html#a815283d2da01c777bc43ed8a8410ec82',1,'Ogre::HlmsBaseProp']]],
  ['uvcount1_58',['UvCount1',['../struct_ogre_1_1_hlms_base_prop.html#a3058629c2fa2d06df547d543005711ed',1,'Ogre::HlmsBaseProp']]],
  ['uvcount2_59',['UvCount2',['../struct_ogre_1_1_hlms_base_prop.html#ac392970d430f9a0eca2db463a49ccbbd',1,'Ogre::HlmsBaseProp']]],
  ['uvcount3_60',['UvCount3',['../struct_ogre_1_1_hlms_base_prop.html#aacd58efb15e23c79dbc64fbc18d21662',1,'Ogre::HlmsBaseProp']]],
  ['uvcount4_61',['UvCount4',['../struct_ogre_1_1_hlms_base_prop.html#a3d2531c2b91fa4f3f177e741c008cfa7',1,'Ogre::HlmsBaseProp']]],
  ['uvcount5_62',['UvCount5',['../struct_ogre_1_1_hlms_base_prop.html#a59810811255534d243025637ad649e6e',1,'Ogre::HlmsBaseProp']]],
  ['uvcount6_63',['UvCount6',['../struct_ogre_1_1_hlms_base_prop.html#a48af42a428f3b83fcce9488eda730004',1,'Ogre::HlmsBaseProp']]],
  ['uvcount7_64',['UvCount7',['../struct_ogre_1_1_hlms_base_prop.html#a6ed33d451345cc19508791f74adbc17c',1,'Ogre::HlmsBaseProp']]],
  ['uvcountptrs_65',['UvCountPtrs',['../struct_ogre_1_1_hlms_base_prop.html#ab098739635586c6b5d1af3c0fa993057',1,'Ogre::HlmsBaseProp']]],
  ['uvdetail0_66',['UvDetail0',['../struct_ogre_1_1_pbs_property.html#a463687d18556ed70d35118e20f300ae8',1,'Ogre::PbsProperty::UvDetail0'],['../struct_ogre_1_1_pbs_mobile_property.html#a2a00954267871233a2c13b8e80da0320',1,'Ogre::PbsMobileProperty::UvDetail0']]],
  ['uvdetail1_67',['UvDetail1',['../struct_ogre_1_1_pbs_property.html#a6cf101ce7617610c426ebed520dd1e91',1,'Ogre::PbsProperty::UvDetail1'],['../struct_ogre_1_1_pbs_mobile_property.html#a7cf9eada2ca8c5924c024bc0d230bf69',1,'Ogre::PbsMobileProperty::UvDetail1']]],
  ['uvdetail2_68',['UvDetail2',['../struct_ogre_1_1_pbs_property.html#ad9a39c3d8effd030d15d4fd4b674e939',1,'Ogre::PbsProperty::UvDetail2'],['../struct_ogre_1_1_pbs_mobile_property.html#aef20e9f0cf4038f243a493562c528edd',1,'Ogre::PbsMobileProperty::UvDetail2']]],
  ['uvdetail3_69',['UvDetail3',['../struct_ogre_1_1_pbs_property.html#afc29ed9c0743d0fe91aff5863ffe0a04',1,'Ogre::PbsProperty::UvDetail3'],['../struct_ogre_1_1_pbs_mobile_property.html#a28bf8525a7b5d0288abf46c8effbcd70',1,'Ogre::PbsMobileProperty::UvDetail3']]],
  ['uvdetailnm0_70',['UvDetailNm0',['../struct_ogre_1_1_pbs_property.html#a4b4c51f8fd078119f40f4e3e06015462',1,'Ogre::PbsProperty::UvDetailNm0'],['../struct_ogre_1_1_pbs_mobile_property.html#ab368794cd70d249a1af1bbe07191c0d3',1,'Ogre::PbsMobileProperty::UvDetailNm0']]],
  ['uvdetailnm1_71',['UvDetailNm1',['../struct_ogre_1_1_pbs_property.html#a0ff30f89ba8adb1e7dd93477f66ffb47',1,'Ogre::PbsProperty::UvDetailNm1'],['../struct_ogre_1_1_pbs_mobile_property.html#ae2065f5ea1292c3c6c223ce01a2ee9e8',1,'Ogre::PbsMobileProperty::UvDetailNm1']]],
  ['uvdetailnm2_72',['UvDetailNm2',['../struct_ogre_1_1_pbs_property.html#aeea22df7402907173915502c489d9a9d',1,'Ogre::PbsProperty::UvDetailNm2'],['../struct_ogre_1_1_pbs_mobile_property.html#a877b6d30c8162923bc943ff98bc7014e',1,'Ogre::PbsMobileProperty::UvDetailNm2']]],
  ['uvdetailnm3_73',['UvDetailNm3',['../struct_ogre_1_1_pbs_property.html#a9ca13bcc5ae788d93d77c4c814ed3173',1,'Ogre::PbsProperty::UvDetailNm3'],['../struct_ogre_1_1_pbs_mobile_property.html#ae2ba7073c060b3ec0e687137def86ded',1,'Ogre::PbsMobileProperty::UvDetailNm3']]],
  ['uvdetailweight_74',['UvDetailWeight',['../struct_ogre_1_1_pbs_property.html#aaa45f68c608f0005be3559d50196ea45',1,'Ogre::PbsProperty::UvDetailWeight'],['../struct_ogre_1_1_pbs_mobile_property.html#aeccf1651047633de46f6d6e54f168312',1,'Ogre::PbsMobileProperty::UvDetailWeight']]],
  ['uvdiffuse_75',['UvDiffuse',['../struct_ogre_1_1_pbs_property.html#a36edaac4ed84336253dcf00ca19ef165',1,'Ogre::PbsProperty::UvDiffuse'],['../struct_ogre_1_1_pbs_mobile_property.html#a60b03b13bd9f716bd4b8cb18ab569d65',1,'Ogre::PbsMobileProperty::UvDiffuse']]],
  ['uvdiffuse0_76',['UvDiffuse0',['../struct_ogre_1_1_unlit_property.html#a4a9d07c36bb9be02d6b72c1bdc407b25',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse1_77',['UvDiffuse1',['../struct_ogre_1_1_unlit_property.html#a017189ec47ab23f487c8f641e6c4caad',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse10_78',['UvDiffuse10',['../struct_ogre_1_1_unlit_property.html#a3064d90099b8960cc88ee448e86bdb13',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse11_79',['UvDiffuse11',['../struct_ogre_1_1_unlit_property.html#a1a81eadc51f9c0c6fb79622478203355',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse12_80',['UvDiffuse12',['../struct_ogre_1_1_unlit_property.html#adea9fe577c9459477ac13d05fb7694af',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse13_81',['UvDiffuse13',['../struct_ogre_1_1_unlit_property.html#a1f18d1961ef991f16f725b90fd21da99',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse14_82',['UvDiffuse14',['../struct_ogre_1_1_unlit_property.html#a03b9f986efe97261b2d1f266c07d459e',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse15_83',['UvDiffuse15',['../struct_ogre_1_1_unlit_property.html#a51da605e999c655394daa1633ba07483',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse2_84',['UvDiffuse2',['../struct_ogre_1_1_unlit_property.html#adeb872b76a933de613f4c6804178d1c0',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse3_85',['UvDiffuse3',['../struct_ogre_1_1_unlit_property.html#a910dd22a0d99a10dce876ea1b3fd9d3e',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse4_86',['UvDiffuse4',['../struct_ogre_1_1_unlit_property.html#a1df7899d2b25f5f0a6d59346e62c36a5',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse5_87',['UvDiffuse5',['../struct_ogre_1_1_unlit_property.html#a5859dbc4cc080f7bb4c69ff69c28e022',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse6_88',['UvDiffuse6',['../struct_ogre_1_1_unlit_property.html#a49fd45170a176294af6f273e56a8bb14',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse7_89',['UvDiffuse7',['../struct_ogre_1_1_unlit_property.html#a8b3bfda83631371fd68bce3e1b246e10',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse8_90',['UvDiffuse8',['../struct_ogre_1_1_unlit_property.html#a5804c83c441b035992b4d81ac5b3e72f',1,'Ogre::UnlitProperty']]],
  ['uvdiffuse9_91',['UvDiffuse9',['../struct_ogre_1_1_unlit_property.html#a3995e6c291d3510370de8ae60e0936e9',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle0_92',['UvDiffuseSwizzle0',['../struct_ogre_1_1_unlit_property.html#adf50e95219961417ad9c39e966efa89a',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle1_93',['UvDiffuseSwizzle1',['../struct_ogre_1_1_unlit_property.html#ac92b10f9cd98e8f28a42aa25bc364717',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle10_94',['UvDiffuseSwizzle10',['../struct_ogre_1_1_unlit_property.html#a9f61d547c6195a335bc8a123a3119871',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle11_95',['UvDiffuseSwizzle11',['../struct_ogre_1_1_unlit_property.html#af860139fa5fbc82439a0d6e1366a8a65',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle12_96',['UvDiffuseSwizzle12',['../struct_ogre_1_1_unlit_property.html#a3d272470f36ea2e178b59433082cee69',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle13_97',['UvDiffuseSwizzle13',['../struct_ogre_1_1_unlit_property.html#a713a15990898e2dbc565aa9ae29f01f6',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle14_98',['UvDiffuseSwizzle14',['../struct_ogre_1_1_unlit_property.html#ae0a36d027f9d446e9fab7e1ef304f9ab',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle15_99',['UvDiffuseSwizzle15',['../struct_ogre_1_1_unlit_property.html#a589b56a42bd6867d756be461af9ccee7',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle2_100',['UvDiffuseSwizzle2',['../struct_ogre_1_1_unlit_property.html#a110b27998fc2f87584defe61ac900d7d',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle3_101',['UvDiffuseSwizzle3',['../struct_ogre_1_1_unlit_property.html#a3ddbb75a15890bd7cb59ac8df26c478b',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle4_102',['UvDiffuseSwizzle4',['../struct_ogre_1_1_unlit_property.html#af51e6675c4da6d42980fa4d4ca1c0c57',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle5_103',['UvDiffuseSwizzle5',['../struct_ogre_1_1_unlit_property.html#ae992bacb2365d79abc62c2c83135af41',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle6_104',['UvDiffuseSwizzle6',['../struct_ogre_1_1_unlit_property.html#ac311525a52aba21ef34a6bbb7ee5310f',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle7_105',['UvDiffuseSwizzle7',['../struct_ogre_1_1_unlit_property.html#a73913563873b1ebde8a2b86ffa54fe8a',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle8_106',['UvDiffuseSwizzle8',['../struct_ogre_1_1_unlit_property.html#a14a597273ad4f18cd2e30fd173cdfb96',1,'Ogre::UnlitProperty']]],
  ['uvdiffuseswizzle9_107',['UvDiffuseSwizzle9',['../struct_ogre_1_1_unlit_property.html#a2fd61aeb85206153008a9a1330055e65',1,'Ogre::UnlitProperty']]],
  ['uvemissive_108',['UvEmissive',['../struct_ogre_1_1_pbs_property.html#ab3bee700bb74eec0518bf4fe5d61d0fc',1,'Ogre::PbsProperty']]],
  ['uvlength_109',['uvLength',['../class_ogre_1_1_shadow_texture_definition.html#a6b5048cef58070a4608897ab718eb9c4',1,'Ogre::ShadowTextureDefinition']]],
  ['uvnormal_110',['UvNormal',['../struct_ogre_1_1_pbs_property.html#a8535ff2f0757f3bb9f9bec6a974432e8',1,'Ogre::PbsProperty::UvNormal'],['../struct_ogre_1_1_pbs_mobile_property.html#adcb9b6ad6056869f47880cb1a093e8f4',1,'Ogre::PbsMobileProperty::UvNormal']]],
  ['uvoffset_111',['uvOffset',['../class_ogre_1_1_shadow_texture_definition.html#a9415b07e2e36a433b61767818fa214d8',1,'Ogre::ShadowTextureDefinition']]],
  ['uvrect_112',['uvRect',['../struct_ogre_1_1_font_1_1_glyph_info.html#a46b20f8f199e3d2f698aa44a6553ab50',1,'Ogre::Font::GlyphInfo']]],
  ['uvroughness_113',['UvRoughness',['../struct_ogre_1_1_pbs_property.html#a6661e3fc093712a1267dcce3d5f1d7ac',1,'Ogre::PbsProperty::UvRoughness'],['../struct_ogre_1_1_pbs_mobile_property.html#a1b26e5dd827e0febcf98d7c722b52f85',1,'Ogre::PbsMobileProperty::UvRoughness']]],
  ['uvsource_114',['uvSource',['../struct_ogre_1_1_pbs_mobile_shader_creation_data.html#a313e17e279cf50eb01c1a4aa0410a272',1,'Ogre::PbsMobileShaderCreationData::uvSource'],['../struct_ogre_1_1_unlit_property_1_1_diffuse_map_ptr.html#aec650b44d996e845b3b86ccb3a69e5e1',1,'Ogre::UnlitProperty::DiffuseMapPtr::uvSource']]],
  ['uvsourceptrs_115',['UvSourcePtrs',['../struct_ogre_1_1_pbs_property.html#a3775d430326255fd382d73fb205bcff8',1,'Ogre::PbsProperty::UvSourcePtrs'],['../struct_ogre_1_1_pbs_mobile_property.html#a127c6343bac97738e18cdc6918a973e2',1,'Ogre::PbsMobileProperty::UvSourcePtrs']]],
  ['uvsourceswizzle_116',['uvSourceSwizzle',['../struct_ogre_1_1_unlit_property_1_1_diffuse_map_ptr.html#ae35f9514e16f3a1985fd04c51a792b21',1,'Ogre::UnlitProperty::DiffuseMapPtr']]],
  ['uvspecular_117',['UvSpecular',['../struct_ogre_1_1_pbs_property.html#aaa78525e10627bb21169658c1b9799e6',1,'Ogre::PbsProperty::UvSpecular'],['../struct_ogre_1_1_pbs_mobile_property.html#ad1def7c4effec980996bbe4a51924e74',1,'Ogre::PbsMobileProperty::UvSpecular']]]
];
